/**
 * @file
 * VuoList_VuoLeapPointable C type definition.
 *
 * @copyright Copyright © 2012–2014 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoLeapPointable_H
#define VuoList_VuoLeapPointable_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoLeapPointable VuoList_VuoLeapPointable
 * A list of @ref VuoLeapPointable elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

/**
 * @typedef VuoList_VuoLeapPointable
 * A list of @ref VuoLeapPointable elements.
 */
#ifndef VuoList_VuoLeapPointable_TYPE_DEFINED
typedef void * VuoList_VuoLeapPointable;
#endif

/**
 * Creates a new list of @ref VuoLeapPointable elements.
 */
VuoList_VuoLeapPointable VuoListCreate_VuoLeapPointable(void);

/**
 * Returns the @ref VuoLeapPointable at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoLeapPointable VuoListGetValueAtIndex_VuoLeapPointable(const VuoList_VuoLeapPointable list, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoLeapPointable(VuoList_VuoLeapPointable list, const VuoLeapPointable value);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoLeapPointable(VuoList_VuoLeapPointable list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoLeapPointable(VuoList_VuoLeapPointable list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoLeapPointable(const VuoList_VuoLeapPointable list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoLeapPointable VuoList_VuoLeapPointable_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoLeapPointable_jsonFromValue(const VuoList_VuoLeapPointable value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoLeapPointable_summaryFromValue(const VuoList_VuoLeapPointable value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoLeapPointable VuoList_VuoLeapPointable_valueFromString(const char *str);
char * VuoList_VuoLeapPointable_stringFromValue(const VuoList_VuoLeapPointable value);
/// @}

/**
 * @}
 */

#endif
