/**
 * @file
 * VuoList_VuoTransform2d C type definition.
 *
 * @copyright Copyright © 2012–2014 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoTransform2d_H
#define VuoList_VuoTransform2d_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoTransform2d VuoList_VuoTransform2d
 * A list of @ref VuoTransform2d elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

/**
 * @typedef VuoList_VuoTransform2d
 * A list of @ref VuoTransform2d elements.
 */
#ifndef VuoList_VuoTransform2d_TYPE_DEFINED
typedef void * VuoList_VuoTransform2d;
#endif

/**
 * Creates a new list of @ref VuoTransform2d elements.
 */
VuoList_VuoTransform2d VuoListCreate_VuoTransform2d(void);

/**
 * Returns the @ref VuoTransform2d at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoTransform2d VuoListGetValueAtIndex_VuoTransform2d(const VuoList_VuoTransform2d list, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoTransform2d(VuoList_VuoTransform2d list, const VuoTransform2d value);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoTransform2d(VuoList_VuoTransform2d list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoTransform2d(VuoList_VuoTransform2d list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoTransform2d(const VuoList_VuoTransform2d list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoTransform2d VuoList_VuoTransform2d_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoTransform2d_jsonFromValue(const VuoList_VuoTransform2d value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoTransform2d_summaryFromValue(const VuoList_VuoTransform2d value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoTransform2d VuoList_VuoTransform2d_valueFromString(const char *str);
char * VuoList_VuoTransform2d_stringFromValue(const VuoList_VuoTransform2d value);
/// @}

/**
 * @}
 */

#endif
